@@ -5,12 +5,12 @@ use warnings;
 package Dancer2::Plugin::ParamKeywords;
 use Dancer2::Plugin;
 
-our $VERSION = 'v0.1.2';
+our $VERSION = 'v0.1.3';
 
 foreach my $source ( qw( route query body ) ) {
     register "$source\_param" => sub {
         my ($dsl, $param)  = @_;
-        $dsl->app->request->params($source)->{$param};
+        %{ $dsl->app->request->params($source) || {} }{$param};
     };
     
     register "$source\_params" => sub {
@@ -58,7 +58,7 @@ Dancer2::Plugin::ParamKeywords - Sugar for the params() keyword
 
 =head1 VERSION
 
-version v0.1.2
+version v0.1.3
 
 =head1 SYNOPSIS
 
